%% Init file for pendulum_matrix_form_final_win
% Initialization file to used to configure setup of the 
% simulink model of the rotary crane with spherical pendulum
%
% Attachment to M.sc Thesis 2012, NTNU
% Author: Oddvar Gjelstenli
% Version: final
% Version date: 2012-08-06

% Define simulation time and sample rate
simstart=0;     %Simulation start time
simstop=120;    %Simulation stop time
Ts=0.01;        %Sample time
% Operator input
    operator_activated=0; %Joystick input enabled 1=true 0=false
% Test signal ramp
    slope=0.5;          %Rise time of 1/slope
    start_time_ramp=10; %ramp start time
    stop_time_ramp=40;  %ramp stop time
    percent=1;          %percentage [0 1] where 1 is 100%
    wind=0;
% Test signal generator hoist
    %ramp
    hoisting_lowering=1; %-1=hoisting 1=lowering 
    %camera measurement
    load heave_test_signal %test signal for the hoist winch
    %sine wave
    amplitude=1;
    frequency=1/5;
    %hoist signal type selector
    selector=2; %1=ramp 2=camera measurement 3=sine
% Test regulator activation deactivation time
    test_reg_on_time=50;  %simtime when regulator is activated
    test_reg_off_time=100;%simtime when regulator is deactivated   
% Test signal on/off
    test_signal_slew=-1;
    test_signal_boom=1;
    test_signal_hoist=0.5;
% Regulator parameters
Kp_alpha=-10;
Kp_beta=20;
Kp_pos=120;
Ki_pos=60;
Kd_pos=0;%0.6*T;
%Regulator test selector
%regulator = 'beta' to test beta regulator
%regulator = 'alpha' to test alpha regulator
%regulator = 'sway' to test alpha+beta regulator
%regulator = 'pos' to test boom tip pos reg
%regulator = 'all' to anti-sway and boom tip position regulator
%regulator = 'off' to turn off all regulators
regulator_test = 'all';
switch regulator_test
    %alpha controller on=1 off=0
    %alpha controller on=1 off=0
    %boomtip positioning controller on=1 off=0
    %regulator activated at test_reg_on/off time
    case 'beta'   
        alpha_control_activated=0; 
        beta_control_activated=1;
        pos_reg_activated=0;
        test_reg_on =1;            
    case 'alpha'
        alpha_control_activated=1; 
        beta_control_activated=0;  
        pos_reg_activated=0;       
        test_reg_on =1;            
    case 'sway'
        alpha_control_activated=1; 
        beta_control_activated=1;  
        pos_reg_activated=0;       
        test_reg_on =1;            
    case 'pos'
        alpha_control_activated=0; 
        beta_control_activated=0;  
        pos_reg_activated=1;       
        test_reg_on =1;            
    case 'all'
        alpha_control_activated=1; 
        beta_control_activated=1;  
        pos_reg_activated=1;       
        test_reg_on =1;    
    case 'off'
        alpha_control_activated=0; 
        beta_control_activated=0;  
        pos_reg_activated=0;       
        test_reg_on =0;            
end 
%% Joystick interface block

%Define joystick axis deadband (All joystick axis has the range [-1 1])
db_slew=0.3;        %Deadband slew axis on joystick
db_luffing=0.3;     %Deadband luffing axis on joystick
db_hoist=0.5;       %Deadband hoist axis on joystick
button_number=11;   %Button number for the button used to activate
                    %the antisway and boom tip positioning regulator
%Define actuator limitatons
max_hoist_velocity=2.2; %Max hoising speed in [m/s]
%% Saturation and time delay
%filter constants in the '1order exp filter' block
T=2;    %Response time for crane machinery dynamics
%% Model
% 'ddot_r_p->dot_r_p' integrator inital values
beta_angle_vel_init=0;%initial angular velocity for beta [rad/s]
alpha_angle_vel_init=0;%initial angular velocity for alpha [rad/s]
% 'dot_r_p->r_p' integrator initial values
beta_angle_init=0;         % initial angle for beta [deg]
alpha_angle_init=0;       % initial angle for alpha [deg]
% 'Crane' block
    %Define actuator limitations
    max_slew_velocity=0.1;
    max_boom_velocity=0.02;
    %Define initial conditions        
    slew_angle_init=270; %Initial slew angle (q_1) [deg]
    boom_angle_init=14; %Initial boom angle (q_2) [deg]
    % 'luffing angle saturation' block and 'dot_q_2->q_2' integrator
        upper_limit_boom=84.2;    %Upper boom limit angle [deg]
        lower_limit_boom=14;      %Lower boom limit angle [deg]    
    % 'ddot_r_b_block' constants
        rad_pedestal=1.75;      % radius of pedestal [m]
        l_b=50;                 % length of boom [m]
        l_p=10;                 % length of pedestal [m]
    % 'Hoist winch' block
        wire_length_init=80;      %initial wire length [m]
        upper_limit_wirelength=99;%max wire length below boom tip [m]
        lower_limit_wirelength=10;%min wire length below boom tip [m]
    % 'Pendulum' block 
        g=9.81;  %gravity constant
        delta=0; %friction coefficient for the pendulum
%% VR Visualization with Graphs
    %Parameters
    % ylim for beta plot in visu figure [deg]
    beta_plot_y_lim=[-15 15];   
    % ylim for alpha plot in visu figure [deg]
    alpha_plot_y_lim=[-15 15];  
    % ylim for slew angle (q_1) plot [deg]
    q1_plot_y_lim=[0 360];      
    % ylim for boom angle (q_2) plot [deg]
    q2_plot_y_lim=[13 85];      
    % ylim for boom and slew angle velocity (actuator input) [rad/s]
    tau_range=[-0.1 0.1];       
    %Run simulation
    sim('pendulum_matrix_form_final_crane_fixed')