% This m-file is used to generate all the plots made in Chapter 6.2
% of the thesis. The plots is made from stored workspace variables 
% generated during the simulations.
%
% Author: Oddvar Gjelstenli
% Master thesis 2012 NTNU
save_fig=0;
%% Plot test signal
clearvars -except save_fig
close all
load('scenario_1.mat')
figure
subplot(3,1,1)
plot(r_c.time,r_c.signals.values(:,1).*(180/pi))
hold on
xlim([0 60])
ylabel('$q_1$ [deg]','Interpreter','latex')
grid on
subplot(3,1,2)
plot(r_c.time,r_c.signals.values(:,2).*(180/pi))
hold on
xlim([0 60])
ylabel('$q_2$ [deg]','Interpreter','latex')
grid on
subplot(3,1,3)
plot(dot_r_c.time,dot_r_c.signals.values)
hold on
xlim([0 60])
ylabel('$[rad/s]$','Interpreter','latex')
h=legend('$\dot{q}_1$','$\dot{q}_2$');
set(h,'Interpreter','latex')
grid on
xlabel('Time [s]','Interpreter','latex')
if(save_fig)
set(gcf, 'PaperPositionMode', 'Auto') 
filename =  sprintf('../figures/test_signal.eps');
print('-painters','-depsc','-r300', filename)
end
%% Plot heave signal
clearvars -except save_fig
close all
load('scenario_2.mat')
figure
subplot(2,1,1)
plot(l_w.time,l_w.signals.values)
hold on
grid on
ylabel('$l_w$ [m]','Interpreter','latex')
subplot(2,1,2)
plot(dot_l_w.time,dot_l_w.signals.values)
hold on
grid on
ylim([-2.2 2.2])
ylabel('$\dot{l}_w$ [m/s]','Interpreter','latex')
xlabel('Time [s]','Interpreter','latex')
%%
if(save_fig)
set(gcf, 'PaperPositionMode', 'Auto') 
filename =  sprintf('../figures/hoist_signal.eps');
print('-painters','-depsc','-r300', filename)
end
%% Plot scenario 1 (no controller - no hoist signal lw=40)
clearvars -except save_fig
close all
load('../Data/scenario_1.mat')
figure
%subplot(5,1,1:2)
plot(r_p.time,r_p.signals.values.*(180/pi))
hold on
grid on
ylabel('[deg]','Interpreter','latex')
h=legend('$\beta_v$','$\alpha_v$');
set(h,'Interpreter','latex')
ylim([-12 12])
%xlim([45 120])
xlabel('Time [s]','Interpreter','latex')
%%
if(save_fig)
set(gcf, 'PaperPositionMode', 'Auto') 
filename =  sprintf('../figures/scenario_1.eps');
print('-painters','-depsc','-r300', filename)
end
%% Plot scenario 2 (no controller - camera hoist signal lw=40)
clearvars -except save_fig
close all
load('../Data/scenario_2.mat')
figure
subplot(3,1,1)
plot(l_w.time,l_w.signals.values)
hold on
grid on
ylabel('$l_w$ [m]','Interpreter','latex')
subplot(3,1,2:3)
plot(r_p.time,r_p.signals.values.*(180/pi))
hold on
grid on
ylabel('[deg]','Interpreter','latex')
h=legend('$\beta_v$','$\alpha_v$');
set(h,'Interpreter','latex')
%ylim([-10 10])
xlabel('Time [s]','Interpreter','latex')
%%
if(save_fig)
set(gcf, 'PaperPositionMode', 'Auto')
filename =  sprintf('../figures/scenario_2.eps');
print('-painters','-depsc','-r300', filename)
end
%% Plot scenario 3 (sway controller,no hoist signal,lw=40,perfect_r_p)
clearvars -except save_fig
close all
load('../Data/scenario_3.mat')
figure
subplot(5,1,1:2)
plot(r_p.time,r_p.signals.values.*(180/pi))
hold on
grid on
ylabel('[deg]','Interpreter','latex')
h=legend('$\beta_v$','$\alpha_v$');
set(h,'Interpreter','latex')
ylim([-5 8])
xlim([45 120])
subplot(5,1,3)
plot(dot_r_c.time,dot_r_c.signals.values)
hold on
grid on
xlim([45 120])
ylabel('[rad/s]','Interpreter','latex')
h=legend('$\tau_{q_1}$','$\tau_{q_2}$');
set(h,'Interpreter','latex')
subplot(5,1,4)
plot(r_c.time,r_c.signals.values(:,1).*(180/pi))
hold on
%plot(r_des.time,r_des.signals.values(:,1).*(180/pi),'r')
ylim([260 280])
xlim([45 120])
grid on
ylabel('$q_1$[deg]','Interpreter','latex')
subplot(5,1,5)
plot(r_c.time,r_c.signals.values(:,2).*(180/pi))
hold on
%plot(r_des.time,r_des.signals.values(:,2).*(180/pi),'r')
grid on
ylim([45 51])
xlim([45 120])
ylabel('$q_2$ [deg]','Interpreter','latex')
xlabel('Time [s]','Interpreter','latex')
%%
if(save_fig)
set(gcf, 'PaperPositionMode', 'Auto')
filename =  sprintf('../figures/scenario_3.eps');
print('-painters','-depsc','-r300', filename)
end
%% Plot scenario 4 (all controller,no hoist signal,lw=40,perfect_r_p)
clearvars -except save_fig
close all
load('../Data/scenario_4.mat')
figure
subplot(5,1,1:2)
plot(r_p.time,r_p.signals.values.*(180/pi))
hold on
grid on
ylabel('[deg]','Interpreter','latex')
h=legend('$\beta_v$','$\alpha_v$');
set(h,'Interpreter','latex')
ylim([-10 10])
xlim([45 120])
subplot(5,1,3)
plot(dot_r_c.time,dot_r_c.signals.values)
hold on
grid on
xlim([45 120])
ylim([-0.05 0.05])
ylabel('[rad/s]','Interpreter','latex')
h=legend('$\tau_{q_1}$','$\tau_{q_2}$');
set(h,'Interpreter','latex')
subplot(5,1,4)
plot(r_c.time,r_c.signals.values(:,1).*(180/pi))
hold on
plot(r_des.time,r_des.signals.values(:,1).*(180/pi),'r')
ylim([265 285])
xlim([45 120])
grid on
ylabel('[deg]','Interpreter','latex')
h=legend('$q_1$','$q_{1des}$');
set(h,'Interpreter','latex')
subplot(5,1,5)
plot(r_c.time,r_c.signals.values(:,2).*(180/pi))
hold on
plot(r_des.time,r_des.signals.values(:,2).*(180/pi),'r')
grid on
ylim([45 50])
xlim([45 120])
ylabel('[deg]','Interpreter','latex')
h=legend('$q_2$','$q_{2des}$');
set(h,'Interpreter','latex')
xlabel('Time [s]','Interpreter','latex')
%%
if(save_fig)
set(gcf, 'PaperPositionMode', 'Auto')
filename =  sprintf('../figures/scenario_4.eps');
print('-painters','-depsc','-r300', filename)
end
%% Plot scenario 5 (all controller,camera hoist signal,lw=40,perfect_r_p)
clearvars -except save_fig
close all
load('../Data/scenario_5.mat')
figure
subplot(5,1,1:2)
plot(r_p.time,r_p.signals.values.*(180/pi))
hold on
grid on
ylabel('[deg]','Interpreter','latex')
h=legend('$\beta_v$','$\alpha_v$');
set(h,'Interpreter','latex')
xlim([45 120])
ylim([-15 15])
subplot(5,1,3)
plot(dot_r_c.time,dot_r_c.signals.values)
hold on
grid on
xlim([45 120])
ylim([-0.1 0.1])
ylabel('[rad/s]','Interpreter','latex')
h=legend('$\tau_{q_1}$','$\tau_{q_2}$');
set(h,'Interpreter','latex')
subplot(5,1,4)
plot(r_c.time,r_c.signals.values(:,1).*(180/pi))
hold on
plot(r_des.time,r_des.signals.values(:,1).*(180/pi),'r')
ylim([265 285])
xlim([45 120])
grid on
ylabel('[deg]','Interpreter','latex')
h=legend('$q_1$','$q_{1des}$');
set(h,'Interpreter','latex')
subplot(5,1,5)
plot(r_c.time,r_c.signals.values(:,2).*(180/pi))
hold on
plot(r_des.time,r_des.signals.values(:,2).*(180/pi),'r')
grid on
ylim([45 52])
xlim([45 120])
ylabel('[deg]','Interpreter','latex')
h=legend('$q_2$','$q_{2des}$');
set(h,'Interpreter','latex')
xlabel('Time [s]','Interpreter','latex')
%%
if(save_fig)
set(gcf, 'PaperPositionMode', 'Auto')
filename =  sprintf('../figures/scenario_5.eps');
print('-painters','-depsc','-r300', filename)
end
%% Plot scenario 6 (all controller,camera hoist signal,lw=40,Kalman_r_p)
clearvars -except save_fig
close all
load('../Data/scenario_6.mat')
figure
subplot(5,1,1:2)
plot(beta_hat.time,beta_hat.signals.values.*(180/pi))
hold on
plot(alpha_hat.time,alpha_hat.signals.values.*(180/pi),'Color',[0 0.5 0])
grid on
ylabel('[deg]','Interpreter','latex')
h=legend('$\beta_v$','$\alpha_v$');
set(h,'Interpreter','latex')
%ylim([-8 5])
xlim([45 120])
subplot(5,1,3)
plot(dot_r_c.time,dot_r_c.signals.values)
hold on
grid on
xlim([45 120])
ylim([-0.1 0.1])
ylabel('[rad/s]','Interpreter','latex')
h=legend('$\tau_{q_1}$','$\tau_{q_2}$');
set(h,'Interpreter','latex')
subplot(5,1,4)
plot(r_c.time,r_c.signals.values(:,1).*(180/pi))
hold on
plot(r_des.time,r_des.signals.values(:,1).*(180/pi),'r')
ylim([265 285])
xlim([45 120])
grid on
ylabel('[deg]','Interpreter','latex')
h=legend('$q_1$','$q_{1des}$');
set(h,'Interpreter','latex')
subplot(5,1,5)
plot(r_c.time,r_c.signals.values(:,2).*(180/pi))
hold on
plot(r_des.time,r_des.signals.values(:,2).*(180/pi),'r')
grid on
ylim([45 52])
xlim([45 120])
ylabel('[deg]','Interpreter','latex')
h=legend('$q_2$','$q_{2des}$');
set(h,'Interpreter','latex')
xlabel('Time [s]','Interpreter','latex')
%%
if(save_fig)
set(gcf, 'PaperPositionMode', 'Auto')
filename =  sprintf('../figures/scenario_6.eps');
print('-painters','-depsc','-r300', filename)
end
%% Plot scenario 7 (no controller,no hoist signal,lw=80,Kalman_r_p)
clearvars -except save_fig
close all
load('../Data/scenario_7.mat')
figure
%subplot(5,1,1:2)
plot(beta_hat.time,beta_hat.signals.values.*(180/pi))
hold on
plot(alpha_hat.time,alpha_hat.signals.values.*(180/pi),'Color',[0 0.5 0])
grid on
ylabel('[deg]','Interpreter','latex')
h=legend('$\beta_v$','$\alpha_v$');
set(h,'Interpreter','latex')
ylim([-10 10])
%xlim([45 120])
xlabel('Time [s]','Interpreter','latex')
%%
if(save_fig)
set(gcf, 'PaperPositionMode', 'Auto')
filename =  sprintf('../figures/scenario_7.eps');
print('-painters','-depsc','-r300', filename)
end
%% Plot scenario 8 (sway controller,no hoist signal,lw=80,kalman_r_p)
clearvars -except save_fig
close all
load('../Data/scenario_8.mat')
figure
subplot(5,1,1:2)
plot(beta_hat.time,beta_hat.signals.values.*(180/pi))
hold on
plot(alpha_hat.time,alpha_hat.signals.values.*(180/pi),'Color',[0 0.5 0])
grid on
ylabel('[deg]','Interpreter','latex')
h=legend('$\beta_v$','$\alpha_v$');
set(h,'Interpreter','latex')
ylim([-8 5])
xlim([45 120])
subplot(5,1,3)
plot(dot_r_c.time,dot_r_c.signals.values)
hold on
grid on
xlim([45 120])
ylabel('[rad/s]','Interpreter','latex')
h=legend('$\tau_{q_1}$','$\tau_{q_2}$');
set(h,'Interpreter','latex')
subplot(5,1,4)
plot(r_c.time,r_c.signals.values(:,1).*(180/pi))
hold on
%plot(r_des.time,r_des.signals.values(:,1).*(180/pi),'r')
ylim([260 290])
xlim([45 120])
grid on
ylabel('$q_1$ [deg]','Interpreter','latex')
subplot(5,1,5)
plot(r_c.time,r_c.signals.values(:,2).*(180/pi))
hold on
%plot(r_des.time,r_des.signals.values(:,2).*(180/pi),'r')
grid on
ylim([45 51])
xlim([45 120])
ylabel('$q_2$ [deg]','Interpreter','latex')
xlabel('Time [s]','Interpreter','latex')
%%
if(save_fig)
set(gcf, 'PaperPositionMode', 'Auto')
filename =  sprintf('../figures/scenario_8.eps');
print('-painters','-depsc','-r300', filename)
end
%% Plot scenario 9 (all controller,no hoist signal,lw=80,kalman_r_p)
clearvars -except save_fig
close all
load('../Data/scenario_9.mat')
figure
subplot(5,1,1:2)
plot(beta_hat.time,beta_hat.signals.values.*(180/pi))
hold on
plot(alpha_hat.time,alpha_hat.signals.values.*(180/pi),'Color',[0 0.5 0])
grid on
ylabel('[deg]','Interpreter','latex')
h=legend('$\beta_v$','$\alpha_v$');
set(h,'Interpreter','latex')
ylim([-10 5])
xlim([45 120])
subplot(5,1,3)
plot(dot_r_c.time,dot_r_c.signals.values)
hold on
grid on
xlim([45 120])
ylim([-0.05 0.05])
ylabel('[rad/s]','Interpreter','latex')
h=legend('$\tau_{q_1}$','$\tau_{q_2}$');
set(h,'Interpreter','latex')
subplot(5,1,4)
plot(r_c.time,r_c.signals.values(:,1).*(180/pi))
hold on
plot(r_des.time,r_des.signals.values(:,1).*(180/pi),'r')
ylim([265 290])
xlim([45 120])
grid on
ylabel('[deg]','Interpreter','latex')
h=legend('$q_1$','$q_{1des}$');
set(h,'Interpreter','latex')
subplot(5,1,5)
plot(r_c.time,r_c.signals.values(:,2).*(180/pi))
hold on
plot(r_des.time,r_des.signals.values(:,2).*(180/pi),'r')
grid on
ylim([45 50])
xlim([45 120])
ylabel('[deg]','Interpreter','latex')
h=legend('$q_2$','$q_{2des}$');
set(h,'Interpreter','latex')
xlabel('Time [s]','Interpreter','latex')
%%
if(save_fig)
set(gcf, 'PaperPositionMode', 'Auto')
filename =  sprintf('../figures/scenario_9.eps');
print('-painters','-depsc','-r300', filename)
end
%% Plot scenario 10 (all controller,camera hoist signal,lw=80,kalman_r_p)
clearvars -except save_fig
close all
load('../Data/scenario_10.mat')
figure
subplot(5,1,1:2)
plot(beta_hat.time,beta_hat.signals.values.*(180/pi))
hold on
plot(alpha_hat.time,alpha_hat.signals.values.*(180/pi),'Color',[0 0.5 0])
grid on
ylabel('[deg]','Interpreter','latex')
h=legend('$\beta_v$','$\alpha_v$');
set(h,'Interpreter','latex')
ylim([-10 5])
xlim([45 120])
subplot(5,1,3)
plot(dot_r_c.time,dot_r_c.signals.values)
hold on
grid on
xlim([45 120])
ylim([-0.05 0.05])
ylabel('[rad/s]','Interpreter','latex')
h=legend('$\tau_{q_1}$','$\tau_{q_2}$');
set(h,'Interpreter','latex')
subplot(5,1,4)
plot(r_c.time,r_c.signals.values(:,1).*(180/pi))
hold on
plot(r_des.time,r_des.signals.values(:,1).*(180/pi),'r')
ylim([265 290])
xlim([45 120])
grid on
ylabel('[deg]','Interpreter','latex')
h=legend('$q_1$','$q_{1des}$');
set(h,'Interpreter','latex')
subplot(5,1,5)
plot(r_c.time,r_c.signals.values(:,2).*(180/pi))
hold on
plot(r_des.time,r_des.signals.values(:,2).*(180/pi),'r')
grid on
ylim([45 50])
xlim([45 120])
ylabel('[deg]','Interpreter','latex')
h=legend('$q_2$','$q_{2des}$');
set(h,'Interpreter','latex')
xlabel('Time [s]','Interpreter','latex')
%%
if(save_fig)
set(gcf, 'PaperPositionMode', 'Auto')
filename =  sprintf('../figures/scenario_10.eps');
print('-painters','-depsc','-r300', filename)
end
%% Plot scenario 11 (all controller,camera hoist signal,lw=80,kalman_r_p,operator)
clearvars -except save_fig
close all
load('../Data/scenario_11.mat')
figure
subplot(5,1,1:2)
plot(beta_hat.time,beta_hat.signals.values.*(180/pi))
hold on
plot(alpha_hat.time,alpha_hat.signals.values.*(180/pi),'Color',[0 0.5 0])
grid on
ylabel('[deg]','Interpreter','latex')
h=legend('$\beta_v$','$\alpha_v$');
set(h,'Interpreter','latex')
ylim([-10 5])
xlim([45 120])
subplot(5,1,3)
plot(dot_r_c.time,dot_r_c.signals.values)
hold on
grid on
xlim([45 120])
ylim([-0.1 0.1])
ylabel('[rad/s]','Interpreter','latex')
h=legend('$\tau_{q_1}$','$\tau_{q_2}$');
set(h,'Interpreter','latex')
subplot(5,1,4)
plot(r_c.time,r_c.signals.values(:,1).*(180/pi))
hold on
plot(r_des.time,r_des.signals.values(:,1).*(180/pi),'r')
ylim([265 320])
xlim([45 120])
grid on
ylabel('[deg]','Interpreter','latex')
h=legend('$q_1$','$q_{1des}$');
set(h,'Interpreter','latex')
subplot(5,1,5)
plot(r_c.time,r_c.signals.values(:,2).*(180/pi))
hold on
plot(r_des.time,r_des.signals.values(:,2).*(180/pi),'r')
grid on
ylim([30 50])
xlim([45 120])
ylabel('[deg]','Interpreter','latex')
h=legend('$q_2$','$q_{2des}$');
set(h,'Interpreter','latex')
xlabel('Time [s]','Interpreter','latex')
%%
if(save_fig)
set(gcf, 'PaperPositionMode', 'Auto')
filename =  sprintf('../figures/scenario_11.eps');
print('-painters','-depsc','-r300', filename)
end
%% Plot scenario 12 (all controller,camera hoist signal,lw=80,kalman_r_p,wind)
clearvars -except save_fig
close all
load('../Data/scenario_12.mat')
figure
subplot(5,1,1:2)
plot(beta_hat.time,beta_hat.signals.values.*(180/pi))
hold on
plot(alpha_hat.time,alpha_hat.signals.values.*(180/pi),'Color',[0 0.5 0])
grid on
ylabel('[deg]','Interpreter','latex')
h=legend('$\beta_v$','$\alpha_v$');
set(h,'Interpreter','latex')
ylim([-10 5])
xlim([45 120])
subplot(5,1,3)
plot(dot_r_c.time,dot_r_c.signals.values)
hold on
grid on
xlim([45 120])
ylim([-0.05 0.05])
ylabel('[rad/s]','Interpreter','latex')
h=legend('$\tau_{q_1}$','$\tau_{q_2}$');
set(h,'Interpreter','latex')
subplot(5,1,4)
plot(r_c.time,r_c.signals.values(:,1).*(180/pi))
hold on
plot(r_des.time,r_des.signals.values(:,1).*(180/pi),'r')
ylim([265 290])
xlim([45 120])
grid on
ylabel('[deg]','Interpreter','latex')
h=legend('$q_1$','$q_{1des}$');
set(h,'Interpreter','latex')
subplot(5,1,5)
plot(r_c.time,r_c.signals.values(:,2).*(180/pi))
hold on
plot(r_des.time,r_des.signals.values(:,2).*(180/pi),'r')
grid on
ylim([30 50])
xlim([45 120])
ylabel('[deg]','Interpreter','latex')
h=legend('$q_2$','$q_{2des}$');
set(h,'Interpreter','latex')
xlabel('Time [s]','Interpreter','latex')
%%
if(save_fig)
set(gcf, 'PaperPositionMode', 'Auto')
filename =  sprintf('../figures/scenario_12.eps');
print('-painters','-depsc','-r300', filename)
end